# coding: utf-8

"""
    Mentortools Marketplace Server

    Mentortools service for ingesting payment-provider webhooks into normalized order events

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from marketplace_server_connector.api.catalog_api import CatalogApi  # noqa: E501


class TestCatalogApi(unittest.IsolatedAsyncioTestCase):
    """CatalogApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = CatalogApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_count_products_v1_catalog_products_count_get(self) -> None:
        """Test case for count_products_v1_catalog_products_count_get

        Count the portal's marketplace products  # noqa: E501
        """
        pass

    async def test_create_account_v1_catalog_accounts_post(self) -> None:
        """Test case for create_account_v1_catalog_accounts_post

        Connect a provider account  # noqa: E501
        """
        pass

    async def test_create_product_v1_catalog_products_post(self) -> None:
        """Test case for create_product_v1_catalog_products_post

        Register a marketplace product  # noqa: E501
        """
        pass

    async def test_delete_account_v1_catalog_accounts_account_id_delete(self) -> None:
        """Test case for delete_account_v1_catalog_accounts_account_id_delete

        Disconnect (delete) an account  # noqa: E501
        """
        pass

    async def test_delete_product_v1_catalog_products_product_id_delete(self) -> None:
        """Test case for delete_product_v1_catalog_products_product_id_delete

        Delete a product  # noqa: E501
        """
        pass

    async def test_get_account_v1_catalog_accounts_account_id_get(self) -> None:
        """Test case for get_account_v1_catalog_accounts_account_id_get

        Get one connected account  # noqa: E501
        """
        pass

    async def test_import_products_v1_catalog_products_import_post(self) -> None:
        """Test case for import_products_v1_catalog_products_import_post

        Bulk-add products by hand (upsert a list)  # noqa: E501
        """
        pass

    async def test_list_accounts_v1_catalog_accounts_get(self) -> None:
        """Test case for list_accounts_v1_catalog_accounts_get

        List the portal's connected provider accounts  # noqa: E501
        """
        pass

    async def test_list_products_v1_catalog_products_get(self) -> None:
        """Test case for list_products_v1_catalog_products_get

        List the portal's marketplace products (paginated)  # noqa: E501
        """
        pass

    async def test_sync_account_products_v1_catalog_accounts_account_id_products_sync_post(self) -> None:
        """Test case for sync_account_products_v1_catalog_accounts_account_id_products_sync_post

        Sync products from one provider account  # noqa: E501
        """
        pass

    async def test_sync_all_products_v1_catalog_products_sync_post(self) -> None:
        """Test case for sync_all_products_v1_catalog_products_sync_post

        Sync products from ALL of the portal's provider accounts  # noqa: E501
        """
        pass

    async def test_update_account_v1_catalog_accounts_account_id_patch(self) -> None:
        """Test case for update_account_v1_catalog_accounts_account_id_patch

        Update an account (rotate credentials / enable-disable)  # noqa: E501
        """
        pass

    async def test_update_product_v1_catalog_products_product_id_patch(self) -> None:
        """Test case for update_product_v1_catalog_products_product_id_patch

        Edit a product (title / external id / archive-restore)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
